Summary:     A high-performance interface between MTAs and content checkers
Name:        amavisd-new
Version:     2.2.1
Release:     9.pp
License:     GPL
Group:       System Environment/Daemons
Source0:     http://www.ijs.si/software/amavisd/%{name}-%{version}.tar.gz
Source1:     amavisd.init
URL:         http://www.ijs.si/software/amavisd/
Buildroot:   /var/tmp/%{name}-root
Vendor:      Mark Martinec <mark.martinec@ijs.si>
Packager:    Peter Pramberger <peter.pramberger@member.fsf.org>
Prereq:      /usr/sbin/groupadd /usr/sbin/useradd /bin/cat /bin/grep
Requires:    sh-utils openldap22 pam db4 >= 4.2 perl(BerkeleyDB)
Requires:    perl(Convert::TNEF) perl(Convert::UUlib) perl(Compress::Zlib)
Requires:    perl(Archive::Tar) perl(Archive::Zip) file > 4.08
Provides:    %{name}.pp
BuildPrereq: gcc >= 2.96 /bin/mkdir /usr/bin/make /usr/bin/install /bin/sed
BuildPrereq: sendmail-devel openldap22-devel
ExclusiveOS: linux

%description
amavisd-new is a high-performance and reliable interface bet-
ween MTAs and one or more content checkers, including virus
scanners, and/or the Mail::SpamAssasin Perl module. It talks
to the MTA via (E)SMTP or LMTP, or by using helper programs.
No timing gaps exist in the design, which could cause a mail
loss. It is normally positioned at or near a central mailer,
not necessarily where the user's mailboxes and final delivery
takes place.


%package milter
Summary:     The milter interface for amavisd-new
Group:       System Environment/Daemons
Requires:    %{name} = %{version}-%{release} %{name}.pp
Provides:    %{name}-milter.pp

%description milter
The %{name}-milter package contains the sendmail milter
interface for amavisd-new.


%prep
%setup -q
# Modify settings
perl -pi -e \
	"s,\'vscan\',\'amavis\',g; \
	 s,/var/amavis,/var/lib/amavis,g; \
	 s,/var/virusmails,/var/lib/amavis/virus,g; \
	" \
	amavisd.conf amavisd.conf-default amavisd.conf-sample \
	amavisd-agent amavisd-nanny


%build
cd helper-progs
export CFLAGS="$RPM_OPT_FLAGS"
./configure \
	--prefix=/usr                                \
	--sysconfdir=/etc                            \
	--localstatedir=/var                         \
	--with-sendmail=/usr/sbin/sendmail           \
	--with-runtime-dir=/var/lib/amavis           \
	--with-sockname=/var/lib/amavis/amavisd.sock \
	--with-user=amavis
cp Makefile tmp_file
sed -e "s:-lnsl:-lnsl -lldap -llber:g" tmp_file > Makefile
rm -f tmp_file
make all


# Do not strip, only compress documentation
%define __os_install_post /usr/lib/rpm/brp-compress


%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/etc
mkdir -p $RPM_BUILD_ROOT/etc/rc.d/init.d
mkdir -p $RPM_BUILD_ROOT/usr/sbin
mkdir -p $RPM_BUILD_ROOT/var/lib/amavis/db
mkdir -p $RPM_BUILD_ROOT/var/lib/amavis/tmp
mkdir -p $RPM_BUILD_ROOT/var/lib/amavis/virus
install -m 0755 amavisd $RPM_BUILD_ROOT/usr/sbin
install -m 0755 amavisd-agent $RPM_BUILD_ROOT/usr/sbin
install -m 0755 amavisd-nanny $RPM_BUILD_ROOT/usr/sbin
install -m 0640 amavisd.conf $RPM_BUILD_ROOT/etc
install -m 0755 %{SOURCE1} $RPM_BUILD_ROOT/etc/rc.d/init.d/amavisd
cd helper-progs
make \
	prefix=$RPM_BUILD_ROOT/usr \
	install


%pre
if ! id -g amavis >/dev/null 2>&1; then
   /usr/sbin/groupadd -r amavis >/dev/null 2>&1
fi
if ! id -u amavis >/dev/null 2>&1; then
   /usr/sbin/useradd -g amavis -G amavis -d /var/lib/amavis \
        -r -s /bin/false amavis >/dev/null 2>&1
fi


%post
/sbin/chkconfig --add amavisd
/sbin/chkconfig amavisd on
if [ -f /var/lock/subsys/amavisd ]; then
   /etc/rc.d/init.d/amavisd restart
fi

%post milter
if ! grep amavis-milter /etc/services >/dev/null 2>&1; then
   echo -e "amavis-milter\t10026/tcp" >> /etc/services
fi
if [ -f /var/lock/subsys/amavisd ]; then
   /etc/rc.d/init.d/amavisd restart
fi
echo
echo "Per default amavis-milter will listen on 127.0.0.1:10026."
echo "You have to configure sendmail to connect to this port."
echo


%preun
if [ $1 = 0 ] ; then
   /sbin/chkconfig amavisd on
   /sbin/chkconfig --del amavisd
   if [ -f /var/lock/subsys/amavisd ]; then
      /etc/rc.d/init.d/amavisd stop
   fi
fi

%preun milter
if [ -f /var/lock/subsys/amavisd ]; then
   /etc/rc.d/init.d/amavisd stop
fi


%postun milter
if [ $1 = 0 ] ; then
   echo
   echo "amavisd-new-milter deinstalled. Please update your"
   echo "sendmail and amavisd-new configs!                 "
   echo
fi


%clean
rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,root)
%doc *README* INSTALL LICENSE MANIFEST RELEASE_NOTES TODO *.patch
%doc amavisd.conf-default amavisd.conf-sample JpegTester.pm *.schema
%doc %dir README_FILES test-messages
%attr(640,root,amavis) %config(noreplace) /etc/amavisd.conf
/etc/rc.d/init.d/*
/usr/sbin/amavis
/usr/sbin/amavisd*
%attr(750,amavis,amavis) %dir /var/lib/amavis
%attr(750,amavis,amavis) %dir /var/lib/amavis/db
%attr(750,amavis,amavis) %dir /var/lib/amavis/tmp
%attr(750,amavis,amavis) %dir /var/lib/amavis/virus

%files milter
%defattr(-,root,root)
%attr(750,root,amavis) /usr/sbin/amavis-milter


%changelog
* Mon Mar 14 2005 peter.pramberger@member.fsf.org
- new version 2.2.1

* Fri Nov 26 2004 peter.pramberger@member.fsf.org
- new version 2.2.0

* Tue Sep 28 2004 peter.pramberger@member.fsf.org
- new version 2.1.2

* Mon May 17 2004 peter.pramberger@member.fsf.org
- new version 20030616-p9

* Thu Mar 18 2004 peter.pramberger@member.fsf.org
- new version 20030616-p8

* Sun Dec 28 2003 peter.pramberger@member.fsf.org
- new version 20030616-p6

* Sat Sep 06 2003 peter.pramberger@member.fsf.org
- new version 20030616-p5

* Sun Jul 20 2003 peter.pramberger@member.fsf.org
- fixed typo in init script
- minor bug fixes

* Sun Jul 13 2003 peter.pramberger@member.fsf.org
- created

